@@ -103,7 +103,7 @@ translate_pressure (gdouble p)
   
   p *= 31;
   pi = p;
-  frac = pi - p;
+  frac = p - pi;
 
   if (pi == 31)
     return info.tool->profile[pi];
@@ -609,7 +609,7 @@ create_main_window ()
   GtkWidget *window;
   GtkWidget *box1;
   GtkWidget *menubar;
-  GtkAcceleratorTable *accelerator_table;
+  GtkAccelGroup *accel_group;
   GtkWidget *area;
 
   info.mainwin = window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -622,12 +622,11 @@ create_main_window ()
   gtk_widget_show (box1);
  
   /* create a menubar */
-  menus_get_main_menubar (&menubar, &accelerator_table);
+  menus_get_main_menubar (&menubar, &accel_group);
   gtk_box_pack_start (GTK_BOX (box1), menubar, FALSE, TRUE, 0);
   gtk_widget_show (menubar);
 
-  /*  Install the accelerator table in the main window  */
-  gtk_window_add_accelerator_table (GTK_WINDOW (window), accelerator_table);
+  gtk_accel_group_attach (accel_group, GTK_OBJECT (window));
 
   area = create_canvas_area();
   gtk_box_pack_start (GTK_BOX (box1), area, TRUE, TRUE, 0);
@@ -695,6 +694,8 @@ main (int argc, char *argv[])
     }
 
   color_init (ngrays);	/* allocate colors */
+
+  menus_create();
   load_gsumirc();
   gsumirc_update_menus();
 
