@@ -193,19 +193,12 @@ GdkPixmap* create_icon_pixmap (GdkWindow *window,
 
 /* Menu handling functions (menus.c) */
 void menus_get_main_menubar   (GtkWidget           **menu,
-			       GtkAcceleratorTable **table);
-void menus_create             (GtkMenuEntry         *entries,
-			       int                   nmenu_entries);
-void menus_set_sensitive      (char                 *path,
-			       int                   sensitive);
+			       GtkAccelGroup       **accel_group);
 void menus_add_path           (char                 *path,
 			       char                 *accelerator);
+void menus_create             (void);
 void menus_store              (void);
 
-gchar *menus_stringify_accelerator  (guint                 keyval, 
-				     GdkModifierType       modifiers);
-
-
 /* from gsumirc.c (loading, saving rc file) */
 void load_gsumirc(void);
 void save_gsumirc(void);
