@@ -119,45 +119,6 @@ update_tool_device(Node *device_rc, char *name)
   tool_box_set_values(tool->id);
 }
 
-/* Copied from gtk_menu_factory_parse_accelerator() */
-static void
-gsumirc_parse_accelerator (const char   *accelerator,
-			   GdkDeviceKey *key)
-{
-  int done;
-
-  g_return_if_fail (accelerator != NULL);
-  g_return_if_fail (key != NULL);
-
-  key->modifiers = 0;
-
-  done = FALSE;
-  while (!done)
-    {
-      if (strncmp (accelerator, "<shift>", 7) == 0)
-        {
-          accelerator += 7;
-          key->modifiers |= GDK_SHIFT_MASK;
-        }
-      else if (strncmp (accelerator, "<alt>", 5) == 0)
-        {
-          accelerator += 5;
-          key->modifiers |= GDK_MOD1_MASK;
-        }
-      else if (strncmp (accelerator, "<control>", 9) == 0)
-        {
-          accelerator += 9;
-          key->modifiers |= GDK_CONTROL_MASK;
-        }
-      else
-        {
-          done = TRUE;
-	  /* Tricky, but works... ("" => keyval = 0, or no translation) */
-          key->keyval = accelerator[0];
-        }
-    }
-}
-
 static void
 update_xinput_device(Node *device_rc, char *name)
 {
@@ -250,11 +211,14 @@ update_xinput_device(Node *device_rc, char *name)
 	    {
 	      if (sn->type == NODE_STRING)
 		{
-		  GdkDeviceKey key;
-		  gsumirc_parse_accelerator (sn->c.s, &key);
-		  
-		  gdk_input_set_key (info->deviceid, j,
-				     key.keyval, key.modifiers);
+		  guint key = 0;
+		  GdkModifierType mods = 0;
+
+		  if (sn->c.s[0] != '\0') /* unnecessary check? */
+		    {
+		      gtk_accelerator_parse (sn->c.s, &key, &mods);
+		      gdk_input_set_key (info->deviceid, j, key, mods);
+		    }
 		}
 	    }
 	}
@@ -498,8 +462,8 @@ update_to_gsumirc()
 		node_list_append(n,node_string_new("key"));
 		node_list_append(n,node_string_new(buf));
 
-		accel = menus_stringify_accelerator (info->keys[j].keyval,
-						     info->keys[j].modifiers);
+		accel = gtk_accelerator_name (info->keys[j].keyval,
+					      info->keys[j].modifiers);
 		node_list_append(n,node_string_new(accel));
 		g_free (accel);
 
