@@ -148,6 +148,7 @@ tool_item_create(ToolInfo *tool_info)
   ti->tool_info = tool_info;
 
   ti->vbox = gtk_vbox_new(FALSE,0);
+  gtk_widget_ref (ti->vbox);
 
   /* create the label */
 
@@ -159,22 +160,23 @@ tool_item_create(ToolInfo *tool_info)
 
   /* frame and the menu */
 
-  ti->frame = gtk_frame_new(NULL);
-  gtk_frame_set_shadow_type(GTK_FRAME(ti->frame),GTK_SHADOW_NONE);
+  ti->frame = gtk_frame_new (NULL);
+  gtk_frame_set_shadow_type (GTK_FRAME(ti->frame),GTK_SHADOW_NONE);
   gtk_box_pack_start (GTK_BOX (ti->vbox), ti->frame, FALSE, FALSE, 0);
-  gtk_widget_show(ti->frame);
+  gtk_widget_show (ti->frame);
 
-  inner_box = gtk_hbox_new(FALSE,2);
-  gtk_container_border_width(GTK_CONTAINER(inner_box),3);
-  gtk_container_add(GTK_CONTAINER(ti->frame), inner_box);
-  gtk_widget_show(inner_box);
+  inner_box = gtk_hbox_new (FALSE,2);
+  gtk_container_border_width (GTK_CONTAINER(inner_box),3);
+  gtk_container_add (GTK_CONTAINER(ti->frame), inner_box);
+  gtk_widget_show (inner_box);
   
   menu = gtk_menu_new();
+  gtk_widget_realize (menu);
   
   menu_item = gtk_menu_item_new();
   gtk_object_set_user_data(GTK_OBJECT(menu_item),ti);
 
-  pm = create_icon_pixmap(ti->vbox->window,PEN_TOOL,gray_pixels);
+  pm = create_icon_pixmap (menu->window, PEN_TOOL, gray_pixels);
   if (!pm)
     g_error("Could not create pen pixmap");
   pixmap = gtk_pixmap_new(pm,NULL);
@@ -190,7 +192,7 @@ tool_item_create(ToolInfo *tool_info)
   menu_item = gtk_menu_item_new();
   gtk_object_set_user_data(GTK_OBJECT(menu_item),ti);
 
-  pm = create_icon_pixmap(ti->vbox->window,ERASER_TOOL,gray_pixels);
+  pm = create_icon_pixmap (menu->window, ERASER_TOOL, gray_pixels);
   if (!pm)
     g_error("Could not create eraser pixmap");
 
@@ -239,6 +241,7 @@ static void
 tool_item_destroy(ToolItem *ti)
 {
   gtk_widget_destroy(ti->vbox);
+  gtk_widget_unref (ti->vbox);
 
   g_free(ti);
 }
@@ -270,6 +273,9 @@ brush_widget_expose (GtkWidget *w, GdkEventExpose *event)
   
   r0 = MIN(w->allocation.width,w->allocation.height)/2;
 
+  if (r0 < 2)
+    return;
+
   gdk_window_clear_area(w->window,
 			0,0,w->allocation.width,
 			w->allocation.height);
@@ -368,6 +374,7 @@ tool_box_set_current_prop(ToolItem *ti)
       toolBox->current_prop = ti;
       
       strncat(buf,ti->name,BUFSIZE-strlen(buf)-1);
+      buf[BUFSIZE-1] = '\0';
       gtk_label_set(GTK_LABEL(toolBox->prop_label),buf);
 
       toolBox->size_data->value = ti->tool_info->size;
@@ -377,12 +384,22 @@ tool_box_set_current_prop(ToolItem *ti)
       gtk_signal_emit_by_name (GTK_OBJECT (toolBox->sens_data), "changed");
 
       gtk_widget_draw (toolBox->brush_widget, NULL);
+
+      options_dialog_set_current_device (ti->tool_info->id);
     }
 }
 
+static void
+tool_box_more_options_cb (void)
+{
+  options_dialog_set_current_device (toolBox->current_prop->tool_info->id);
+  options_dialog_create ();
+}
+
 void
 tool_box_create()
 {
+  GtkWidget *button;
   GtkWidget *main_vbox;
   GtkWidget *separator;
   GtkWidget *hbox;
@@ -505,6 +522,14 @@ tool_box_create()
       gtk_widget_show (toolBox->brush_widget);
       gtk_widget_show (hbox);
 
+      button = gtk_button_new_with_label ("More Options..");
+      gtk_box_pack_start (GTK_BOX(main_vbox), button, FALSE, FALSE, 5);
+      gtk_widget_show (button);
+
+      gtk_signal_connect (GTK_OBJECT (button), "clicked",
+			  GTK_SIGNAL_FUNC (tool_box_more_options_cb),
+			  NULL);
+      
       gtk_widget_show(main_vbox);
     }
 }
@@ -519,14 +544,25 @@ tool_box_show()
 void
 tool_box_destroy()
 {
-  GList *tmp_list = toolBox->items;
-  
-  for (;tmp_list;tmp_list=tmp_list->next) {
-    tool_item_destroy((ToolItem *)tmp_list->data);
-  }
+  GList *tmp_list;
+  static int in_destroy = 0;
 
-  g_free(toolBox);
-  toolBox = NULL;
+  if (toolBox && !in_destroy)
+    {
+      in_destroy = TRUE;
+      gtk_widget_destroy (toolBox->shell);
+      in_destroy = FALSE;
+      
+      tmp_list = toolBox->items;
+      for (;tmp_list;tmp_list=tmp_list->next) 
+	{
+	  tool_item_destroy((ToolItem *)tmp_list->data);
+	}
+      g_list_free (toolBox->items);
+      
+      g_free(toolBox);
+      toolBox = NULL;
+    }
 }
 
 static ToolItem *
@@ -580,8 +616,8 @@ tool_box_remove_device(guint32 devid)
       if (toolBox->current == ti)
 	toolBox->current = NULL;
 
-      toolBox->items = g_list_remove(toolBox->items,
-				     tool_box_find_device(devid));
+      toolBox->items = g_list_remove(toolBox->items, ti);
+
       g_return_if_fail (toolBox->items != NULL);
       
       if (toolBox->current_prop == ti)
